<?php declare(strict_types=1);

namespace BitBadger\PDODocument\Query;

use BitBadger\PDODocument\{Field, Query};

/**
 * Queries for retrieving documents
 */
class Find
{
    /**
     * Query to retrieve a document by its ID
     *
     * @param string $tableName The name of the table from which a document should be retrieved
     * @return string The SELECT statement to retrieve a document by its ID
     */
    public static function byId(string $tableName): string
    {
        return Query::selectFromTable($tableName) . ' WHERE ' . Query::whereById();
    }

    /**
     * Query to retrieve documents using a comparison on JSON fields
     *
     * @param string $tableName The name of the table from which documents should be retrieved
     * @param Field[] $fields The field comparison to match
     * @param string $conjunction How to handle multiple conditions (optional; defaults to `AND`)
     * @return string The SELECT statement to retrieve documents by field comparison
     */
    public static function byFields(string $tableName, array $fields, string $conjunction = 'AND'): string
    {
        return Query::selectFromTable($tableName) . ' WHERE ' . Query::whereByFields($fields, $conjunction);
    }
}
